==> dokuwiki-2012.10.13.tgz: dokuwiki/inc/lang/is/lang.php <==
<?php
/**
 * is language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesIs.php?view=co
 * @author Hrannar Baldursson <hrannar.baldursson@gmail.com>
 * @author Ólafur Gunnlaugsson <oli@audiotools.com>
 * @author Erik Bjørn Pedersen <erik.pedersen@shaw.ca>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Breyta þessari síðu';
$lang['btn_source']            = 'Skoða wikikóða';
$lang['btn_show']              = 'Sýna síðu';
$lang['btn_create']            = 'Búa til þessa síðu';
$lang['btn_search']            = 'Leit';
$lang['btn_save']              = 'Vista';
$lang['btn_preview']           = 'Forskoða';
$lang['btn_top']               = 'Efst á síðu';
$lang['btn_newer']             = '<< nýrra';
$lang['btn_older']             = 'eldra >>';
$lang['btn_revs']              = 'breytingaskrá';
$lang['btn_recent']            = 'Nýlegar breytingar';
$lang['btn_upload']            = 'Hlaða upp';
$lang['btn_cancel']            = 'Hætta við';
$lang['btn_index']             = 'Atriðaskrá';
$lang['btn_secedit']           = 'Breyta';
$lang['btn_login']             = 'Innskrá';
$lang['btn_logout']            = 'Útskrá';
$lang['btn_admin']             = 'Stjórnandi';
$lang['btn_update']            = 'Uppfæra';
$lang['btn_delete']            = 'Eyða';
$lang['btn_back']              = 'Til baka';
$lang['btn_backlink']          = 'Hvað tengist hingað';
$lang['btn_backtomedia']       = 'Aftur til miðlaskrá';
$lang['btn_subscribe']         = 'Vakta';
$lang['btn_unsubscribe']       = 'Afvakta';
$lang['btn_profile']           = 'Uppfæra notanda';
$lang['btn_reset']             = 'Endurstilla';
$lang['btn_draft']             = 'Breyta uppkasti';
$lang['btn_recover']           = 'Endurheimta uppkast';
$lang['btn_draftdel']          = 'Eyða uppkasti';
$lang['btn_revert']            = 'Endurheimta';
$lang['btn_register']          = 'Skráning';
$lang['loggedinas']            = 'Innskráning sem';
$lang['user']                  = 'Notendanafn';
$lang['pass']                  = 'Aðgangsorð';
$lang['newpass']               = 'Nýtt aðgangsorð';
$lang['oldpass']               = 'Staðfesta núverandi (gamla) aðgangsorðið';
$lang['passchk']               = 'Aðgangsorð (aftur)';
$lang['remember']              = 'Muna.';
$lang['fullname']              = 'Fullt nafn þitt*';
$lang['email']                 = 'Tölvupóstfangið þitt*';
$lang['profile']               = 'Notendastillingar';
$lang['badlogin']              = 'Því miður, notandanafn eða aðgangsorð var rangur.';
$lang['minoredit']             = 'Minniháttar breyting';
$lang['draftdate']             = 'Uppkast vistað sjálfkrafa';
$lang['nosecedit']             = 'Síðunni var breytt á meðan, upplýsingar um svæðið voru úreltar og öll síðan því endurhlaðin.';
$lang['regmissing']            = 'Afsakið, en þú verður að fylla út í allar eyður.';
$lang['reguexists']            = 'Afsakið, notandi með þessu nafni er þegar skráður inn.';
$lang['regsuccess']            = 'Notandi hefur verið búinn til og aðgangsorð sent í tölvupósti.';
$lang['regsuccess2']           = 'Notandi hefur verið búinn til.';
$lang['regmailfail']           = 'Það lítur út fyrir villu við sendingu aðgangsorðs. Vinsamlegast hafðu samband við stjórnanda.';
$lang['regbadmail']            = 'Uppgefinn tölvupóstur virðist ógildur - teljir þú þetta vera villu, hafðu þá samband við stjórnanda.';
$lang['regbadpass']            = 'Aðgangsorðin tvö eru ekki eins, vinsamlegast reyndu aftur.';
$lang['regpwmail']             = 'DokuWiki aðgangsorðið þitt';
$lang['reghere']               = 'Ertu ekki með reikning? Skráðu þig';
$lang['profna']                = 'Þessi wiki leyfir ekki breytingar á notendaupplýsingum';
$lang['profnochange']          = 'Enga breytingar vistaðar';
$lang['profnoempty']           = 'Það er ekki leyfilegt að skilja nafn og póstfang eftir óútfyllt';
$lang['profchanged']           = 'Notendaupplýsingum breytt';
$lang['pwdforget']             = 'Gleymt aðgangsorð? Fáðu nýtt';
$lang['resendna']              = 'Þessi wiki styður ekki endursendingar aðgangsorðs';
$lang['resendpwdmissing']      = 'Afsakið, þú verður að út eyðublaðið allt';
$lang['resendpwdnouser']       = 'Afsakið, notandi finnst ekki.';
$lang['resendpwdbadauth']      = 'Afsakið, þessi sannvottunorð er ekki gild. Gakktu úr skugga um að þú notaðir að ljúka staðfesting hlekkur.';
$lang['resendpwdconfirm']      = 'Staðfesting hlekkur hefur verið send með tölvupósti.';
$lang['resendpwdsuccess']      = 'Nýja aðgangsorðið hefur verið sent með tölvupósti.';
$lang['license']               = 'Nema annað sé tekið fram, efni á þessari wiki er leyfð undir eftirfarandi leyfi:';
$lang['licenseok']             = 'Athugið: Með því að breyta þessari síðu samþykkir þú að leyfisveitandi efni undir eftirfarandi leyfi:';
$lang['searchmedia']           = 'Leit skrárheiti:';
$lang['searchmedia_in']        = 'Leit í %s';
$lang['txt_upload']            = 'Veldu skrá til innhleðslu';
$lang['txt_filename']          = 'Innhlaða sem (valfrjálst)';
$lang['txt_overwrt']           = 'Skrifa yfir skrá sem þegar er til';
$lang['lockedby']              = 'Læstur af';
$lang['lockexpire']            = 'Læsing rennur út eftir';
$lang['nothingfound']          = 'Ekkert fannst';
$lang['mediaselect']           = 'Miðlaskrá';
$lang['fileupload']            = 'Hlaða inn miðlaskrá';
$lang['uploadsucc']            = 'Innhlaðning tókst';
$lang['uploadfail']            = 'Villa í innhlaðningu';
$lang['uploadwrong']           = 'Innhleðslu neitað. Skrár með þessari endingu eru ekki leyfðar.';
$lang['uploadexist']           = 'Skrá var þegar til staðar.';
$lang['uploadbadcontent']      = 'Innhlaðið efni var ekki við að %s skrárendingu.';
$lang['uploadspam']            = 'Þessi innhlaðning er útilokuð vegna ruslpósts svarturlisti.';
$lang['uploadxss']             = 'Þessi innhlaðning er útilokuð vegna hugsanlega skaðlegum efni.';
$lang['uploadsize']            = 'Innhlaðið skrá var of stór. (Hámark eru %s)';
$lang['deletesucc']            = 'Skrá %s hefur verið eytt.';
$lang['namespaces']            = 'Nafnrýmar';
$lang['mediafiles']            = 'Tiltækar skrár í';
$lang['js']['searchmedia']     = 'Leita að skrám';
$lang['js']['hidedetails']     = 'Fela upplýsingar';
$lang['js']['linkwiz']         = 'Tengill-leiðsagnarforrit';
$lang['js']['linkto']          = 'Tengja';
$lang['js']['del_confirm']     = 'Á örugglega að eyða valdar skrár?';
$lang['mediaview']             = 'Sjá upprunalega skrá';
$lang['mediaroot']             = 'rót';
$lang['mediaextchange']        = 'Skrárending var breytt úr .%s til .%s!';
$lang['reference']             = 'Tilvísanir til';
$lang['ref_inuse']             = 'Ekki hægt að eyða skráin, því það er enn notað af eftirfarandi síðum:';
$lang['ref_hidden']            = 'Sumar tilvísanir eru að síður sem þú hefur ekki leyfi til að lesa';
$lang['hits']                  = 'Samsvör';
$lang['quickhits']             = 'Samsvörun síðunöfn';
$lang['toc']                   = 'Efnisyfirlit';
$lang['current']               = 'nú';
$lang['yours']                 = 'Þín útgáfa';
$lang['diff']                  = 'Sýna ágreiningur til núverandi endurskoðun';
$lang['diff2']                 = 'Sýna ágreiningur meðal valið endurskoðun';
$lang['line']                  = 'Lína';
$lang['breadcrumb']            = 'Snefill';
$lang['youarehere']            = 'Þú ert hér';
$lang['lastmod']               = 'Síðast breytt';
$lang['by']                    = 'af';
$lang['deleted']               = 'eytt';
$lang['created']               = 'myndað';
$lang['restored']              = 'Breytt aftur til fyrri útgáfu';
$lang['external_edit']         = 'utanaðkomandi breyta';
$lang['summary']               = 'Forskoða';
$lang['noflash']               = 'Það þarf <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash viðbót</a> til að sýna sumt efnið á þessari síðu';
$lang['download']              = 'Hlaða niður til kóðabút';
$lang['mail_newpage']          = 'síðu bætt við:';
$lang['mail_changed']          = 'síðu breytt:';
$lang['mail_new_user']         = 'nýr notandi:';
$lang['mail_upload']           = 'Innhlaðið skrá:';
$lang['qb_bold']               = 'Feitletraður texti';
$lang['qb_italic']             = 'Skáletraður texti';
$lang['qb_underl']             = 'Undirstrikaður texti';
$lang['qb_code']               = 'Kóðatraður texti';
$lang['qb_strike']             = 'Yfirstrikaður texti';
$lang['qb_h1']                 = 'Fyrsta stigs fyrirsögn';
$lang['qb_h2']                 = 'Annars stigs fyrirsögn';
$lang['qb_h3']                 = 'Þriðja stigs fyrirsögn';
$lang['qb_h4']                 = 'Fjórða stigs fyrirsögn';
$lang['qb_h5']                 = 'Fimmta stigs fyrirsögn';
$lang['qb_h']                  = 'Fyrirsögn';
$lang['qb_hs']                 = 'Veldu fyrirsögn';
$lang['qb_hplus']              = 'Hærra stigs fyrirsögn';
$lang['qb_hminus']             = 'Lægri stigs fyrirsögn';
$lang['qb_hequal']             = 'Sama stigs fyrirsögn';
$lang['qb_link']               = 'Innri tengill';
$lang['qb_extlink']            = 'Ytri tengill (muna að setja http:// á undan)';
$lang['qb_hr']                 = 'Lárétt lína (notist sparlega)';
$lang['qb_ol']                 = 'Númeraðaðan listatriði';
$lang['qb_ul']                 = 'Ónúmeraðaðan listatriði';
$lang['qb_media']              = 'Bæta inn myndum og öðrum skrám';
$lang['qb_sig']                = 'Undirskrift þín auk tímasetningu';
$lang['qb_smileys']            = 'Broskallar';
$lang['qb_chars']              = 'Sértækir stafir';
$lang['admin_register']        = 'Setja nýjan notenda inn';
$lang['metaedit']              = 'Breyta lýsigögnum';
$lang['metasaveerr']           = 'Vistun lýsigagna mistókst';
$lang['metasaveok']            = 'Lýsigögn vistuð';
$lang['img_backto']            = 'Aftur til';
$lang['img_title']             = 'Heiti';
$lang['img_caption']           = 'Skýringartexti';
$lang['img_date']              = 'Dagsetning';
$lang['img_fname']             = 'Skrárheiti';
$lang['img_fsize']             = 'Stærð';
$lang['img_artist']            = 'Myndsmiður';
$lang['img_copyr']             = 'Útgáfuréttur';
$lang['img_format']            = 'Forsnið';
$lang['img_camera']            = 'Myndavél';
$lang['img_keywords']          = 'Lykilorðir';
$lang['i_retry']               = 'Reyna aftur';

==> dokuwiki-2024.02.06p0.tgz: dokuwiki/inc/lang/is/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * is language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesIs.php?view=co
 *
 * @author Hrannar Baldursson <hrannar.baldursson@gmail.com>
 * @author Ólafur Gunnlaugsson <oli@audiotools.com>
 * @author Erik Bjørn Pedersen <erik.pedersen@shaw.ca>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Breyta þessari síðu';
$lang['btn_source']            = 'Skoða wikikóða';
$lang['btn_show']              = 'Sýna síðu';
$lang['btn_create']            = 'Búa til þessa síðu';
$lang['btn_search']            = 'Leit';
$lang['btn_save']              = 'Vista';
$lang['btn_preview']           = 'Forskoða';
$lang['btn_top']               = 'Efst á síðu';
$lang['btn_newer']             = '<< nýrra';
$lang['btn_older']             = 'eldra >>';
$lang['btn_revs']              = 'breytingaskrá';
$lang['btn_recent']            = 'Nýlegar breytingar';
$lang['btn_upload']            = 'Hlaða upp';
$lang['btn_cancel']            = 'Hætta við';
$lang['btn_index']             = 'Atriðaskrá';
$lang['btn_secedit']           = 'Breyta';
$lang['btn_login']             = 'Innskrá';
$lang['btn_logout']            = 'Útskrá';
$lang['btn_admin']             = 'Stjórnandi';
$lang['btn_update']            = 'Uppfæra';
$lang['btn_delete']            = 'Eyða';
$lang['btn_back']              = 'Til baka';
$lang['btn_backlink']          = 'Hvað tengist hingað';
$lang['btn_subscribe']         = 'Vakta';
$lang['btn_profile']           = 'Uppfæra notanda';
$lang['btn_reset']             = 'Endurstilla';
$lang['btn_draft']             = 'Breyta uppkasti';
$lang['btn_recover']           = 'Endurheimta uppkast';
$lang['btn_draftdel']          = 'Eyða uppkasti';
$lang['btn_revert']            = 'Endurheimta';
$lang['btn_register']          = 'Skráning';
$lang['btn_img_backto']        = 'Aftur til %s';
$lang['loggedinas']            = 'Innskráning sem:';
$lang['user']                  = 'Notendanafn';
$lang['pass']                  = 'Aðgangsorð';
$lang['newpass']               = 'Nýtt aðgangsorð';
$lang['oldpass']               = 'Staðfesta núverandi (gamla) aðgangsorðið';
$lang['passchk']               = 'Aðgangsorð (aftur)';
$lang['remember']              = 'Muna.';
$lang['fullname']              = 'Fullt nafn þitt*';
$lang['email']                 = 'Tölvupóstfangið þitt*';
$lang['profile']               = 'Notendastillingar';
$lang['badlogin']              = 'Því miður, notandanafn eða aðgangsorð var rangur.';
$lang['minoredit']             = 'Minniháttar breyting';
$lang['draftdate']             = 'Uppkast vistað sjálfkrafa';
$lang['nosecedit']             = 'Síðunni var breytt á meðan, upplýsingar um svæðið voru úreltar og öll síðan því endurhlaðin.';
$lang['js']['searchmedia']     = 'Leita að skrám';
$lang['js']['hidedetails']     = 'Fela upplýsingar';
$lang['js']['linkwiz']         = 'Tengill-leiðsagnarforrit';
$lang['js']['linkto']          = 'Tengja';
$lang['js']['del_confirm']     = 'Á örugglega að eyða valdar skrár?';
$lang['regmissing']            = 'Afsakið, en þú verður að fylla út í allar eyður.';
$lang['reguexists']            = 'Afsakið, notandi með þessu nafni er þegar skráður inn.';
$lang['regsuccess']            = 'Notandi hefur verið búinn til og aðgangsorð sent í tölvupósti.';
$lang['regsuccess2']           = 'Notandi hefur verið búinn til.';
$lang['regmailfail']           = 'Það lítur út fyrir villu við sendingu aðgangsorðs. Vinsamlegast hafðu samband við stjórnanda.';
$lang['regbadmail']            = 'Uppgefinn tölvupóstur virðist ógildur - teljir þú þetta vera villu, hafðu þá samband við stjórnanda.';
$lang['regbadpass']            = 'Aðgangsorðin tvö eru ekki eins, vinsamlegast reyndu aftur.';
$lang['regpwmail']             = 'DokuWiki aðgangsorðið þitt';
$lang['reghere']               = 'Ertu ekki með reikning? Skráðu þig';
$lang['profna']                = 'Þessi wiki leyfir ekki breytingar á notendaupplýsingum';
$lang['profnochange']          = 'Enga breytingar vistaðar';
$lang['profnoempty']           = 'Það er ekki leyfilegt að skilja nafn og póstfang eftir óútfyllt';
$lang['profchanged']           = 'Notendaupplýsingum breytt';
$lang['pwdforget']             = 'Gleymt aðgangsorð? Fáðu nýtt';
$lang['resendna']              = 'Þessi wiki styður ekki endursendingar aðgangsorðs';
$lang['resendpwdmissing']      = 'Afsakið, þú verður að út eyðublaðið allt';
$lang['resendpwdnouser']       = 'Afsakið, notandi finnst ekki.';
$lang['resendpwdbadauth']      = 'Afsakið, þessi sannvottunorð er ekki gild. Gakktu úr skugga um að þú notaðir að ljúka staðfesting hlekkur.';
$lang['resendpwdconfirm']      = 'Staðfesting hlekkur hefur verið send með tölvupósti.';
$lang['resendpwdsuccess']      = 'Nýja aðgangsorðið hefur verið sent með tölvupósti.';
$lang['license']               = 'Nema annað sé tekið fram, efni á þessari wiki er leyfð undir eftirfarandi leyfi:';
$lang['licenseok']             = 'Athugið: Með því að breyta þessari síðu samþykkir þú að leyfisveitandi efni undir eftirfarandi leyfi:';
$lang['searchmedia']           = 'Leit skrárheiti:';
$lang['searchmedia_in']        = 'Leit í %s';
$lang['txt_upload']            = 'Veldu skrá til innhleðslu:';
$lang['txt_filename']          = 'Innhlaða sem (valfrjálst):';
$lang['txt_overwrt']           = 'Skrifa yfir skrá sem þegar er til';
$lang['lockedby']              = 'Læstur af:';
$lang['lockexpire']            = 'Læsing rennur út eftir:';
$lang['nothingfound']          = 'Ekkert fannst';
$lang['mediaselect']           = 'Miðlaskrá';
$lang['uploadsucc']            = 'Innhlaðning tókst';
$lang['uploadfail']            = 'Villa í innhlaðningu';
$lang['uploadwrong']           = 'Innhleðslu neitað. Skrár með þessari endingu eru ekki leyfðar.';
$lang['uploadexist']           = 'Skrá var þegar til staðar.';
$lang['uploadbadcontent']      = 'Innhlaðið efni var ekki við að %s skrárendingu.';
$lang['uploadspam']            = 'Þessi innhlaðning er útilokuð vegna ruslpósts svarturlisti.';
$lang['uploadxss']             = 'Þessi innhlaðning er útilokuð vegna hugsanlega skaðlegum efni.';
$lang['uploadsize']            = 'Innhlaðið skrá var of stór. (Hámark eru %s)';
$lang['deletesucc']            = 'Skrá %s hefur verið eytt.';
$lang['namespaces']            = 'Nafnrýmar';
$lang['mediafiles']            = 'Tiltækar skrár í';
$lang['mediaview']             = 'Sjá upprunalega skrá';
$lang['mediaroot']             = 'rót';
$lang['mediaextchange']        = 'Skrárending var breytt úr .%s til .%s!';
$lang['reference']             = 'Tilvísanir til';
$lang['ref_inuse']             = 'Ekki hægt að eyða skráin, því það er enn notað af eftirfarandi síðum:';
$lang['ref_hidden']            = 'Sumar tilvísanir eru að síður sem þú hefur ekki leyfi til að lesa';
$lang['hits']                  = 'Samsvör';
$lang['quickhits']             = 'Samsvörun síðunöfn';
$lang['toc']                   = 'Efnisyfirlit';
$lang['current']               = 'nú';
$lang['yours']                 = 'Þín útgáfa';
$lang['diff']                  = 'Sýna ágreiningur til núverandi endurskoðun';
$lang['diff2']                 = 'Sýna ágreiningur meðal valið endurskoðun';
$lang['line']                  = 'Lína';
$lang['breadcrumb']            = 'Snefill:';
$lang['youarehere']            = 'Þú ert hér:';
$lang['lastmod']               = 'Síðast breytt:';
$lang['by']                    = 'af';
$lang['deleted']               = 'eytt';
$lang['created']               = 'myndað';
$lang['restored']              = 'Breytt aftur til fyrri útgáfu (%s)';
$lang['external_edit']         = 'utanaðkomandi breyta';
$lang['summary']               = 'Forskoða';
$lang['noflash']               = 'Það þarf <a href="http://get.adobe.com/flashplayer">Adobe Flash viðbót</a> til að sýna sumt efnið á þessari síðu';
$lang['download']              = 'Hlaða niður til kóðabút';
$lang['mail_newpage']          = 'síðu bætt við:';
$lang['mail_changed']          = 'síðu breytt:';
$lang['mail_new_user']         = 'nýr notandi:';
$lang['mail_upload']           = 'Innhlaðið skrá:';
$lang['qb_bold']               = 'Feitletraður texti';
$lang['qb_italic']             = 'Skáletraður texti';
$lang['qb_underl']             = 'Undirstrikaður texti';
$lang['qb_code']               = 'Kóðatraður texti';
$lang['qb_strike']             = 'Yfirstrikaður texti';
$lang['qb_h1']                 = 'Fyrsta stigs fyrirsögn';
$lang['qb_h2']                 = 'Annars stigs fyrirsögn';
$lang['qb_h3']                 = 'Þriðja stigs fyrirsögn';
$lang['qb_h4']                 = 'Fjórða stigs fyrirsögn';
$lang['qb_h5']                 = 'Fimmta stigs fyrirsögn';
$lang['qb_h']                  = 'Fyrirsögn';
$lang['qb_hs']                 = 'Veldu fyrirsögn';
$lang['qb_hplus']              = 'Hærra stigs fyrirsögn';
$lang['qb_hminus']             = 'Lægri stigs fyrirsögn';
$lang['qb_hequal']             = 'Sama stigs fyrirsögn';
$lang['qb_link']               = 'Innri tengill';
$lang['qb_extlink']            = 'Ytri tengill (muna að setja http:// á undan)';
$lang['qb_hr']                 = 'Lárétt lína (notist sparlega)';
$lang['qb_ol']                 = 'Númeraðaðan listatriði';
$lang['qb_ul']                 = 'Ónúmeraðaðan listatriði';
$lang['qb_media']              = 'Bæta inn myndum og öðrum skrám';
$lang['qb_sig']                = 'Undirskrift þín auk tímasetningu';
$lang['qb_smileys']            = 'Broskallar';
$lang['qb_chars']              = 'Sértækir stafir';
$lang['metaedit']              = 'Breyta lýsigögnum';
$lang['metasaveerr']           = 'Vistun lýsigagna mistókst';
$lang['metasaveok']            = 'Lýsigögn vistuð';
$lang['img_title']             = 'Heiti:';
$lang['img_caption']           = 'Skýringartexti:';
$lang['img_date']              = 'Dagsetning:';
$lang['img_fname']             = 'Skrárheiti:';
$lang['img_fsize']             = 'Stærð:';
$lang['img_artist']            = 'Myndsmiður:';
$lang['img_copyr']             = 'Útgáfuréttur:';
$lang['img_format']            = 'Forsnið:';
$lang['img_camera']            = 'Myndavél:';
$lang['img_keywords']          = 'Lykilorðir:';
$lang['i_retry']               = 'Reyna aftur';
